@@ -20,8 +20,8 @@ our @EXPORT = qw(
   compile_output_to_note
 );
 
-# ABSTRACT: test-time utilities for checking C headers, libraries, or OS features
-our $VERSION = '0.05'; # VERSION
+# ABSTRACT: Test-time utilities for checking C headers, libraries, or OS features
+our $VERSION = '0.06'; # VERSION
 
 
 do {
@@ -70,8 +70,8 @@ sub compile_with_alien ($)
 
   if($alien->can('dist_dir'))
   {
-    my $dir = File::Spec->catdir($alien->dist_dir, 'lib');
-    unshift @LD_LIBRARY_PATH, $dir if -d $dir;
+    my $dir = eval { File::Spec->catdir($alien->dist_dir, 'lib') };
+    unshift @LD_LIBRARY_PATH, $dir if defined $dir && -d $dir;
   }
   
   my $tdir = File::Spec->catdir($FindBin::Bin, File::Spec->updir, '_test');
@@ -121,11 +121,11 @@ __END__
 
 =head1 NAME
 
-Test::CChecker - test-time utilities for checking C headers, libraries, or OS features
+Test::CChecker - Test-time utilities for checking C headers, libraries, or OS features
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
